﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Data;
using Infragistics.Windows.DataPresenter;

namespace DataTableMultiValueConverter
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        DataSet set = new DataSet();
        public MainWindow()
        {
            InitializeComponent(); 
            //Add two tables
            set.Tables.Add(BuildTable("Parent"));

            grid1.DataSource = set.Tables[0].DefaultView;

        }


        // Notes from Bob Balok
        // Here is the scenerio for my data.  The user has budgeted some hours for a resource - OriginalTotal.  Those hours 
        // get distributed in weekly cells that cover the length of the project, therefore the need for a dynamic number
        // of weekly columns depending on the length of the project.  The user can redistribute the hours to the weeks
        // they want but the NewTotal must match the OriginalTotal before they navigate away from the record being
        // updated.  It is when the NewTotal cell value does not match the OriginalTotal cell value that I want the
        // foreground color of the NewTotal to change to indicate to the user there is still a difference from
        // OriginalTotal.

        // Notes from testing:
        // The color of the cells change when I navigate off the row/DataRecord.  I want to color of the cells to change after the cell
        // value has been updated and the two columns are not equal.

 private DataTable BuildTable(string name)
    {
       
        System.Data.DataTable table = new DataTable(name);
        DataColumn column;
        DataRow row;

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "id";
        column.ReadOnly = false;
        table.Columns.Add(column);

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "OriginalTotal";
        column.AutoIncrement = false;
        column.Caption = "Original Total";
        column.ReadOnly = false;
        column.Unique = false;
        table.Columns.Add(column);

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "NewTotal";
        column.AutoIncrement = false;
        column.Caption = "New Total";
        column.ReadOnly = false;
        column.Unique = false;
        table.Columns.Add(column);

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "Week1";
        column.AutoIncrement = false;
        column.Caption = "Week 1";
        column.ReadOnly = false;
        column.Unique = false;
        table.Columns.Add(column);

        column = new DataColumn();
        column.DataType = System.Type.GetType("System.Int32");
        column.ColumnName = "Week2";
        column.AutoIncrement = false;
        column.Caption = "Week 2";
        column.ReadOnly = false;
        column.Unique = false;
        table.Columns.Add(column);

        DataColumn[] PrimaryKeyColumns = new DataColumn[1];
        PrimaryKeyColumns[0] = table.Columns["id"];
        table.PrimaryKey = PrimaryKeyColumns;

        for (int i = 0; i <= 20; i++)
        {
            row = table.NewRow();
            row["id"] = i;
            row["OriginalTotal"] = 10;
            row["NewTotal"] = 10;
            row["Week1"] = 5;
            row["Week2"] = 5;
            table.Rows.Add(row);
        }
        return table;

    }

 private void grid1_EditModeEnded(object sender, Infragistics.Windows.DataPresenter.Events.EditModeEndedEventArgs e)
 {
     DataRecord gridRec = e.Cell.Record as DataRecord;
     System.Data.DataView editView = new System.Data.DataView();
     decimal enteredHours = 0;
     decimal cellHours = 0;
     for (int i = 3; i <= 4; i++)
     {
         cellHours = Convert.ToDecimal(gridRec.Cells[i].Value);
         enteredHours += cellHours;
     }
     // Update data source so VauluConverter can change colors if necessary
     editView.Table = set.Tables[0];
     editView.RowFilter = "id = '" + gridRec.Cells["id"].Value.ToString() + "'";
     editView[0].Row.BeginEdit();
     editView[0]["NewTotal"] = enteredHours;  // reset value to zero
     editView[0].Row.AcceptChanges();
     gridRec.Cells["NewTotal"].Value = enteredHours;

 }

 private void grid1_EditModeEnding(object sender, Infragistics.Windows.DataPresenter.Events.EditModeEndingEventArgs e)
 {

 }

 private void grid1_RecordActivating(object sender, Infragistics.Windows.DataPresenter.Events.RecordActivatingEventArgs e)
 {
     if (e.Record is DataRecord)
         e.Record.IsSelected = true;
 }

 private void grid1_RecordActivated(object sender, Infragistics.Windows.DataPresenter.Events.RecordActivatedEventArgs e)
 {
     if (e.Record is DataRecord)
         e.Record.IsSelected = true;
 }

    }
}
